@@ -1,5 +1,5 @@
 /*
-  Copyright @ 2003 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -60,6 +60,9 @@ extern WandExport double
 extern WandExport EndianType
   MagickGetImageEndian(MagickWand *);
 
+extern WandExport FilterType
+  MagickGetImageFilter(MagickWand *);
+
 extern WandExport GravityType
   MagickGetImageGravity(MagickWand *);
 
@@ -174,11 +177,9 @@ extern WandExport MagickBooleanType
   MagickGetImageGreenPrimary(MagickWand *,double *,double *,double *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
-  MagickGetImagePage(MagickWand *,size_t *,size_t *,ssize_t *,
-    ssize_t *),
+  MagickGetImagePage(MagickWand *,size_t *,size_t *,ssize_t *,ssize_t *),
   MagickGetImagePixelColor(MagickWand *,const ssize_t,const ssize_t,
     PixelWand *),
-  MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *,double *),
@@ -280,6 +281,7 @@ extern WandExport MagickBooleanType
   MagickSetImageEndian(MagickWand *,const EndianType),
   MagickSetImageExtent(MagickWand *,const size_t,const size_t),
   MagickSetImageFilename(MagickWand *,const char *),
+  MagickSetImageFilter(MagickWand *,const FilterType),
   MagickSetImageFormat(MagickWand *,const char *),
   MagickSetImageFuzz(MagickWand *,const double),
   MagickSetImageGamma(MagickWand *,const double),
